DocumentView

Struct DocumentView 

pub struct DocumentView<'a> { /* private fields */ }
Borrowed semantic view of one immutable XmlDocument generation.

Implementations

Source

impl<'a> DocumentView<'a>

pub const fn identity(self) -> DocumentIdentity

Return the owning document identity.

pub const fn generation(self) -> u64

Return the immutable generation represented by this view.

pub fn xml(self) -> &'a str

Return the serialized XML backing this parsed view.

pub fn root(self) -> NodeIdentity

Return the document root identity.

pub fn root_element(self) -> NodeIdentity

Return the root element identity.

pub fn node_count(self) -> usize

Return the number of parser nodes in this generation.

pub fn node_for_id( self, value: &str, registrations: &[IdAttributeRegistration], ) -> Option<NodeIdentity>

Resolve an ID using standard spellings plus caller registrations.

pub fn document_order( self, identity: NodeIdentity, ) -> Result<usize, XmlDocumentError>

Return deterministic document order for a current tree-node identity.

pub fn node_order( self, identity: NodeIdentity, ) -> Result<SemanticOrder, XmlDocumentError>

Return a total order key for a current tree node.

pub fn attribute_order( self, identity: &AttributeIdentity, ) -> Result<SemanticOrder, XmlDocumentError>

Return a total order key for a current attribute node.

pub fn namespace_order( self, identity: &NamespaceIdentity, ) -> Result<SemanticOrder, XmlDocumentError>

Return a total order key for a current namespace node.

pub fn attribute_identity( self, owner: NodeIdentity, namespace: Option<&str>, local_name: &str, ) -> Result<AttributeIdentity, XmlDocumentError>

Identify an attribute by expanded name on a current owner element.

pub fn namespace_identities( self, owner: NodeIdentity, ) -> Result<Vec<NamespaceIdentity>, XmlDocumentError>

Return the in-scope XPath namespace nodes owned by one current element.