XmlDocumentPolicy

Trait XmlDocumentPolicy 

pub trait XmlDocumentPolicy: Sealed { }
Operation policy snapshots that can configure owned-document parsing.

This sealed trait keeps XML parser policy derived from the same immutable signing, verification, encryption, or decryption snapshot used by the subsequent operation. Applications cannot create a second parser-only configuration path that drifts from operation enforcement.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors