#[non_exhaustive]pub enum PolicyViolation {
Algorithm {
operation: &'static str,
algorithm: String,
},
ResourceLimit {
resource: &'static str,
maximum: usize,
actual: usize,
},
InvalidResourceLimit {
resource: &'static str,
requirement: &'static str,
actual: usize,
},
KeyTrust {
reason: &'static str,
},
XmlInput {
reason: &'static str,
},
Uri {
operation: &'static str,
reason: &'static str,
},
KeySize {
operation: &'static str,
key_type: &'static str,
minimum_bits: usize,
maximum_bits: usize,
actual_bits: usize,
},
InvalidKeyMaterial {
operation: &'static str,
key_type: &'static str,
reason: &'static str,
},
}Expand description
A typed rejection produced by an operation policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Algorithm
An algorithm is outside the operation allowlist.
Fields
ResourceLimit
An input exceeds a configured resource ceiling.
Fields
InvalidResourceLimit
A configured resource limit violates a structural policy requirement.
Fields
KeyTrust
The selected key source or trust mode is disallowed.
XmlInput
XML parser behavior is disallowed.
Uri
A URI class is outside the operation policy.
Fields
KeySize
An RSA key falls outside the operation’s configured strength range.
Fields
InvalidKeyMaterial
RSA key material is structurally invalid.