ResourcePolicy

Struct ResourcePolicy 

pub struct ResourcePolicy {
Show 29 fields pub max_xml_nodes: usize, pub max_references: usize, pub max_transforms_per_reference: usize, pub max_xml_base_components: usize, pub max_xml_base_resolution_bytes: usize, pub max_canonicalized_bytes: usize, pub max_external_resource_bytes: usize, pub max_external_resource_total_bytes: usize, pub max_encryption_plaintext_bytes: usize, pub max_xml_document_bytes: usize, pub max_encryption_recipients: usize, pub max_encryption_metadata_bytes: usize, pub max_key_candidates: usize, pub max_base64_transform_input_bytes: usize, pub max_base64_transform_output_bytes: usize, pub max_xpath_expressions: usize, pub max_xpath_expression_bytes: usize, pub max_xpath_expression_complexity: usize, pub max_xpath_context_evaluations: usize, pub max_xpath_evaluation_work: usize, pub max_xpath_mirror_string_bytes: usize, pub max_xpath_string_work_bytes: usize, pub max_xpath_namespace_bindings: usize, pub max_xpath_namespace_bytes: usize, pub max_xpath_filters: usize, pub max_node_set_filter_work: usize, pub max_node_set_entries: usize, pub max_node_set_owned_string_bytes: usize, pub max_node_set_cumulative_owned_string_bytes: usize,
}
Resource ceilings shared by parsing, transforms, and cryptographic output.

Fields

max_xml_nodes: usize

Maximum XML nodes in one parsed document.

max_references: usize

Maximum references in one signature or manifest.

max_transforms_per_reference: usize

Maximum transforms in one reference.

max_xml_base_components: usize

Maximum inherited xml:base components in one URI resolution.

max_xml_base_resolution_bytes: usize

Maximum cumulative bytes processed while resolving xml:base URIs.

max_canonicalized_bytes: usize

Maximum canonical bytes retained across one signature operation.

max_external_resource_bytes: usize

Maximum decoded external resource bytes.

max_external_resource_total_bytes: usize

Maximum bytes in the complete external map and cumulatively dereferenced.

max_encryption_plaintext_bytes: usize

Maximum XMLEnc plaintext bytes.

max_xml_document_bytes: usize

Maximum caller-owned XML bytes accepted by any document operation.

max_encryption_recipients: usize

Maximum independently wrapped recipients.

max_encryption_metadata_bytes: usize

Maximum caller-controlled XMLEnc metadata bytes per field.

max_key_candidates: usize

Maximum key and certificate candidates inspected by one operation.

max_base64_transform_input_bytes: usize

Maximum bytes accepted by Base64 transforms before decoding.

max_base64_transform_output_bytes: usize

Maximum cumulative bytes emitted by Base64 transforms in one operation.

max_xpath_expressions: usize

Maximum XPath expressions evaluated by one signature operation.

max_xpath_expression_bytes: usize

Maximum UTF-8 bytes in one XPath expression.

max_xpath_expression_complexity: usize

Maximum structural complexity accepted for one XPath expression.

max_xpath_context_evaluations: usize

Maximum context-node evaluations for one ordinary XPath transform.

max_xpath_evaluation_work: usize

Maximum conservative XPath node-evaluation work per operation.

max_xpath_mirror_string_bytes: usize

Maximum source strings copied into the XPath mirror.

max_xpath_string_work_bytes: usize

Maximum conservative XPath string-processing work per operation.

max_xpath_namespace_bindings: usize

Maximum namespace bindings captured by one XPath expression.

max_xpath_namespace_bytes: usize

Maximum aggregate namespace prefix and URI bytes per XPath expression.

max_xpath_filters: usize

Maximum filters in one XPath Filter 2.0 transform.

max_node_set_filter_work: usize

Maximum cumulative node-set entries visited by filtering transforms.

max_node_set_entries: usize

Maximum entries materialized in one exact node set.

max_node_set_owned_string_bytes: usize

Maximum owned string bytes in one materialized node set.

max_node_set_cumulative_owned_string_bytes: usize

Maximum cumulative owned node-set string bytes per operation.

Implementations

Source

impl ResourcePolicy

pub fn validate(&self) -> Result<(), PolicyViolation>

Validate policy values against non-configurable implementation ceilings.