#[non_exhaustive]pub enum ProviderError {
Unsupported {
operation: ProviderOperation,
algorithm: Option<String>,
},
InvalidKeySize {
expected: usize,
actual: usize,
},
InvalidOutputSize {
operation: ProviderOperation,
expected: usize,
actual: usize,
},
InvalidOutputSizeRange {
operation: ProviderOperation,
minimum: usize,
maximum: usize,
actual: usize,
},
InvalidInput(ProviderInputError),
AuthenticationFailed,
Random(String),
}Expand description
Failure returned by a cryptographic provider.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
The selected provider does not implement the operation/parameters.
Fields

operation: ProviderOperationRequested operation.
InvalidKeySize
A key has the wrong size for the selected algorithm.
InvalidOutputSize
A provider reported success but returned bytes that violate the selected operation’s fixed-size output contract.
Fields

operation: ProviderOperationOperation whose output contract was violated.
InvalidOutputSizeRange
A provider reported success but returned bytes outside the selected operation’s variable-size output contract.
Fields

operation: ProviderOperationOperation whose output contract was violated.
InvalidInput(ProviderInputError)
Input framing, padding, or primitive initialization is invalid.
AuthenticationFailed
Authenticated decryption or key-wrap integrity validation failed.
Random(String)
Operating-system randomness was unavailable.