#[non_exhaustive]pub enum KeyResolutionError {
AlgorithmMismatch,
InvalidCertificate,
InvalidPublicKey,
AmbiguousCertificate,
UnsupportedDigestAlgorithm(String),
Chain(X509ChainError),
SystemTime,
}Expand description
Failures while applying KeyResolverConfig to parsed key material.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlgorithmMismatch
A configured or embedded key does not match the signature method.
InvalidCertificate
An embedded certificate could not be parsed completely.
InvalidPublicKey
Configured or embedded public key DER could not be parsed completely.
AmbiguousCertificate
More than one configured certificate satisfies all X.509 selectors.
UnsupportedDigestAlgorithm(String)
An X.509 selector uses a digest algorithm unsupported by this crate.
Chain(X509ChainError)
Embedded certificate path validation failed.
SystemTime
System time was unavailable for certificate validation.