pub type HmacSha1VerificationKey = HmacVerificationKey;Expand description
Compatibility name for the verification key originally limited to HMAC-SHA1.
Aliased Type
pub struct HmacSha1VerificationKey { /* private fields */ }pub type HmacSha1VerificationKey = HmacVerificationKey;Compatibility name for the verification key originally limited to HMAC-SHA1.
pub struct HmacSha1VerificationKey { /* private fields */ }