#[non_exhaustive]pub enum KeyInfoWriteError {
InvalidCertificatePem,
InvalidCertificateFormat {
label: String,
},
InvalidCertificateDer,
SigningKey(SigningKeyError),
CertificateKeyMismatch,
}Expand description
Errors while preparing XMLDSig signing <KeyInfo> output.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidCertificatePem
PEM input could not be parsed.
InvalidCertificateFormat
PEM block was not an X.509 certificate.
InvalidCertificateDer
DER bytes could not be decoded as one complete X.509 certificate.
SigningKey(SigningKeyError)
The signing key could not expose public-key material for validation.
CertificateKeyMismatch
The configured certificate does not contain the signing key’s public key.