X509ChainError

Enum X509ChainError 

#[non_exhaustive]
pub enum X509ChainError { InvalidDepth, InvalidDer { kind: &'static str, message: String, }, UntrustedRoot, DepthExceeded(usize), CertificateNotValid(usize), IssuerNotCa(usize), PathLengthExceeded { position: usize, limit: u32, }, InvalidKeyUsage { position: usize, required: &'static str, }, InvalidSignature(usize), InvalidCrl(usize), Revoked(usize), }
Certificate-chain validation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidDepth

The configured path limit cannot contain a certificate.



InvalidDer

A certificate or CRL is malformed DER.

Fields

kind: &'static str

Object type being parsed.

message: String

Parser diagnostic.



UntrustedRoot

The ordered embedded path cannot be completed to a configured anchor.



DepthExceeded(usize)

The path contains more certificates than allowed.



CertificateNotValid(usize)

A certificate is outside its validity period.



IssuerNotCa(usize)

An issuer certificate is not authorized to issue certificates.



PathLengthExceeded

A CA path-length constraint is violated.

Fields

position: usize

Position of the constraining CA certificate.

limit: u32

Maximum permitted subordinate CA count.



InvalidKeyUsage

A certificate key usage extension forbids the required operation.

Fields

position: usize

Position of the certificate in the validated path.

required: &'static str

RFC 5280 key usage required for the operation.



InvalidSignature(usize)

A certificate signature does not verify under its issuer key.



InvalidCrl(usize)

A CRL is not valid for the selected verification time or issuer.



Revoked(usize)

A path certificate was revoked by an applicable CRL.