pub struct DocumentView<'a> { /* private fields */ }Expand description
Borrowed semantic view of one immutable XmlDocument generation.
Implementations
Sourceimpl<'a> DocumentView<'a>
impl<'a> DocumentView<'a>
Sourcepub const fn identity(self) -> DocumentIdentity
pub const fn identity(self) -> DocumentIdentity
Return the owning document identity.
Sourcepub const fn generation(self) -> u64
pub const fn generation(self) -> u64
Return the immutable generation represented by this view.
Sourcepub fn root(self) -> NodeIdentity
pub fn root(self) -> NodeIdentity
Return the document root identity.
Sourcepub fn root_element(self) -> NodeIdentity
pub fn root_element(self) -> NodeIdentity
Return the root element identity.
Sourcepub fn node_count(self) -> usize
pub fn node_count(self) -> usize
Return the number of parser nodes in this generation.
Sourcepub fn node_for_id(
self,
value: &str,
registrations: &[IdAttributeRegistration],
) -> Option<NodeIdentity>
pub fn node_for_id( self, value: &str, registrations: &[IdAttributeRegistration], ) -> Option<NodeIdentity>
Resolve an ID using standard spellings plus caller registrations.
Sourcepub fn document_order(
self,
identity: NodeIdentity,
) -> Result<usize, XmlDocumentError>
pub fn document_order( self, identity: NodeIdentity, ) -> Result<usize, XmlDocumentError>
Return deterministic document order for a current tree-node identity.
Sourcepub fn node_order(
self,
identity: NodeIdentity,
) -> Result<SemanticOrder, XmlDocumentError>
pub fn node_order( self, identity: NodeIdentity, ) -> Result<SemanticOrder, XmlDocumentError>
Return a total order key for a current tree node.
Sourcepub fn attribute_order(
self,
identity: &AttributeIdentity,
) -> Result<SemanticOrder, XmlDocumentError>
pub fn attribute_order( self, identity: &AttributeIdentity, ) -> Result<SemanticOrder, XmlDocumentError>
Return a total order key for a current attribute node.
Sourcepub fn namespace_order(
self,
identity: &NamespaceIdentity,
) -> Result<SemanticOrder, XmlDocumentError>
pub fn namespace_order( self, identity: &NamespaceIdentity, ) -> Result<SemanticOrder, XmlDocumentError>
Return a total order key for a current namespace node.
Sourcepub fn attribute_identity(
self,
owner: NodeIdentity,
namespace: Option<&str>,
local_name: &str,
) -> Result<AttributeIdentity, XmlDocumentError>
pub fn attribute_identity( self, owner: NodeIdentity, namespace: Option<&str>, local_name: &str, ) -> Result<AttributeIdentity, XmlDocumentError>
Identify an attribute by expanded name on a current owner element.
Sourcepub fn namespace_identities(
self,
owner: NodeIdentity,
) -> Result<Vec<NamespaceIdentity>, XmlDocumentError>
pub fn namespace_identities( self, owner: NodeIdentity, ) -> Result<Vec<NamespaceIdentity>, XmlDocumentError>
Return the in-scope XPath namespace nodes owned by one current element.