PolicyViolation

Enum PolicyViolation 

#[non_exhaustive]
pub enum PolicyViolation { Algorithm { operation: &'static str, algorithm: String, }, ResourceLimit { resource: &'static str, maximum: usize, actual: usize, }, InvalidResourceLimit { resource: &'static str, requirement: &'static str, actual: usize, }, KeyTrust { reason: &'static str, }, XmlInput { reason: &'static str, }, Uri { operation: &'static str, reason: &'static str, }, KeySize { operation: &'static str, key_type: &'static str, minimum_bits: usize, maximum_bits: usize, actual_bits: usize, }, InvalidKeyMaterial { operation: &'static str, key_type: &'static str, reason: &'static str, }, }
A typed rejection produced by an operation policy.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Algorithm

An algorithm is outside the operation allowlist.

Fields

operation: &'static str

Operation evaluating the algorithm.

algorithm: String

Stable algorithm URI or diagnostic name.



ResourceLimit

An input exceeds a configured resource ceiling.

Fields

resource: &'static str

Resource whose consumption was rejected.

maximum: usize

Effective policy ceiling.

actual: usize

Observed consumption.



InvalidResourceLimit

A configured resource limit violates a structural policy requirement.

Fields

resource: &'static str

Resource whose configured limit was rejected.

requirement: &'static str

Required property of the configured limit.

actual: usize

Rejected configured value.



KeyTrust

The selected key source or trust mode is disallowed.

Fields

reason: &'static str

Non-secret reason suitable for diagnostics.



XmlInput

XML parser behavior is disallowed.

Fields

reason: &'static str

Non-secret reason suitable for diagnostics.



Uri

A URI class is outside the operation policy.

Fields

operation: &'static str

Operation evaluating the URI.

reason: &'static str

Non-sensitive reason suitable for diagnostics.



KeySize

An RSA key falls outside the operation’s configured strength range.

Fields

operation: &'static str

Operation evaluating the key.

key_type: &'static str

Stable key-family diagnostic.

minimum_bits: usize

Configured minimum modulus width.

maximum_bits: usize

Non-configurable implementation ceiling.

actual_bits: usize

Observed normalized modulus width.



InvalidKeyMaterial

RSA key material is structurally invalid.

Fields

operation: &'static str

Operation evaluating the key.

key_type: &'static str

Stable key-family diagnostic.

reason: &'static str

Non-secret structural rejection reason.