SignatureBuilderError

Enum SignatureBuilderError 

pub enum SignatureBuilderError {
Show 14 variants InvalidNamespacePrefix(String), InvalidNamespaceUri(String), NamespacePrefixConflict(String), InvalidId { element: &'static str, value: String, }, MissingReference, Policy(PolicyViolation), InvalidXPath(String), SigningAlgorithmDisabled(&'static str), Serialization(Error), InvalidUtf8(FromUtf8Error), GeneratedXml(Error), Canonicalization(C14nError), MissingGeneratedSignedInfo, GeneratedMutation(XmlMutationError),
}
Errors produced while validating or serializing an XMLDSig template.

Variants



InvalidNamespacePrefix(String)

A namespace prefix was not a supported XML NCName.



InvalidNamespaceUri(String)

A namespace URI could not be represented in an XML 1.0 declaration.



NamespacePrefixConflict(String)

An XPath binding would rebind the prefix used by XMLDSig elements.



InvalidId

An XMLDSig Id attribute was not a valid XML NCName.

Fields

element: &'static str

XMLDSig element carrying the Id attribute.

value: String

Rejected attribute value.



MissingReference

XMLDSig requires at least one reference in SignedInfo.



Policy(PolicyViolation)

The immutable signing policy rejected the template.



InvalidXPath(String)

An XPath parameter cannot be parsed or exceeds its resource bounds.



SigningAlgorithmDisabled(&'static str)

SHA-1 algorithms are available for verification but not new signatures.



Serialization(Error)

The XML writer failed.



InvalidUtf8(FromUtf8Error)

The writer unexpectedly emitted bytes that are not UTF-8.



GeneratedXml(Error)

The generated template could not be parsed under the selected policy.



Canonicalization(C14nError)

The generated SignedInfo could not be canonicalized.



MissingGeneratedSignedInfo

The generated template did not contain its required SignedInfo child.



GeneratedMutation(XmlMutationError)

The generated template could not be prepared for policy validation.