pub enum SignatureBuilderError {
InvalidNamespacePrefix(String),
InvalidId {
element: &'static str,
value: String,
},
MissingReference,
SigningAlgorithmDisabled(&'static str),
Serialization(Error),
InvalidUtf8(FromUtf8Error),
}Expand description
Errors produced while validating or serializing an XMLDSig template.
Variants
InvalidNamespacePrefix(String)
A namespace prefix was not a supported XML NCName.
InvalidId
An XMLDSig Id attribute was not a valid XML NCName.
Fields
MissingReference
XMLDSig requires at least one reference in SignedInfo.
SigningAlgorithmDisabled(&'static str)
SHA-1 algorithms are available for verification but not new signatures.
Serialization(Error)
The XML writer failed.
InvalidUtf8(FromUtf8Error)
The writer unexpectedly emitted bytes that are not UTF-8.