Streaming XML mutation helpers for the XMLDSig signing pipeline.
Signing cannot mutate roxmltree’s read-only DOM. These helpers validate
structure with roxmltree, then rewrite the document with quick-xml.
Enums
- XmlMutation
Error - Errors produced by XMLDSig XML mutation helpers.
Functions
- append_
signature_ to_ root - Append a generated XMLDSig
<Signature>template as the last child of the source document root. - fill_
digest_ values - Fill XMLDSig
<DigestValue>elements in document order. - fill_
key_ info - Fill the direct
<Signature>/<KeyInfo>child with XML child content. - fill_
signature_ value - Fill the direct
<Signature>/<SignatureValue>child for a signing template. - fill_
signature_ values - Fill XMLDSig
<SignatureValue>elements in document order. - fill_
signed_ info_ digest_ values - Fill
<DigestValue>elements for direct<SignedInfo>/<Reference>children.