pub enum XmlMutationError {
XmlParse(Error),
Read(Error),
Write(Error),
InvalidUtf8(FromUtf8Error),
InvalidSignatureTemplate,
ValueCountMismatch {
element: &'static str,
expected: usize,
actual: usize,
},
MissingRootElement,
}Expand description
Errors produced by XMLDSig XML mutation helpers.
Variants
XmlParse(Error)
Input XML or generated template is not parseable XML.
Read(Error)
The streaming XML reader failed.
Write(Error)
The streaming XML writer failed.
InvalidUtf8(FromUtf8Error)
The writer unexpectedly emitted non-UTF-8 bytes.
InvalidSignatureTemplate
A template did not contain exactly one XMLDSig <Signature> root.
ValueCountMismatch
A replacement call supplied a different number of values than matching elements.
Fields
MissingRootElement
The source XML did not contain a root element that can receive a signature.